db

package
v0.0.0-...-f6a3790 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 9, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func InitPool

func InitPool() *pgxpool.Pool

InitPool attempts to initialize the PostgreSQL connection pool. It logs a warning if initialization fails and returns nil, allowing the app to continue. Returns the connection pool or nil if initialization failed.

Types

This section is empty.

Jump to